# Welcome

Have you ever wanted to contribute to the coolest cloud technology?
We will help you understand the organization of the Kubernetes project and direct you to the best places to get started.
You'll be able to pick up issues, write code to fix them, and get your work reviewed and merged.

This document is the single source of truth for how to contribute to the code base.
Feel free to browse the [open issues](https://github.com/kubernetes/community/issues?q=is%3Aissue+is%3Aopen+label%3Aarea%2Fcontributor-guide) and file new ones, all feedback welcome!

## Contributor Guide

Welcome to Kubernetes! This guide is broken up into the following sections. 
It is recommended that you follow these steps in order. 

- [Welcome](#welcome) - this page 
- [Prerequisites](#prerequisites) - things you need to complete before contributing
- [Your First Contribution](first-contribution.md) - things you need to know before your first contribution
- [Contributing](contributing.md) - the main guide with contributor information

## Resources Available

- [Kubernetes Contributor Playground](#kubernetes-contributor-playground)
- [Contributor Workshops](#contributor-workshops)
- [Community](#community)
  - [Communication](#communication-1)
  - [Events](#events)
    - [Meetups](#meetups)
  - [Mentorship](#mentorship)
- [Advanced Topics](#advanced-topics)

# Prerequisites

Before submitting code to the project you should first take care of the following prerequisites.
These steps are checked by a bot during your first submission, so doing these steps first will make your first contribution easier: 

## Sign the CLA

Before you can contribute, you will need to sign the [Contributor License Agreement](/CLA.md).  

## Code of Conduct

Please make sure to read and observe our [Code of Conduct](/code-of-conduct.md) and [Community Values](/values.md)

## Setting up your development environment

If you haven’t set up your environment, check the [developer resources](/contributors/devel/README.md#setting-up-your-dev-environment-coding-and-debugging).

## Community Expectations and Roles

Kubernetes is a community project.
Consequently, it is wholly dependent on its community to provide a productive, friendly and collaborative environment.

- Read and review the [Community Expectations](expectations.md) for an understanding of code and review expectations.
- See [Community Membership](/community-membership.md) for a list the various responsibilities of contributor roles. You are encouraged to move up this contributor ladder as you gain experience.

# Kubernetes Contributor Playground

If you are looking for a safe place, where you can familiarize yourself with (some of) the Kubernetes Project's review and pull request processes, then the [Kubernetes Contributor Playground](https://github.com/kubernetes-sigs/contributor-playground/) is the right place for you.

## Contributor Workshops

A [Youtube playlist](https://www.youtube.com/playlist?list=PL69nYSiGNLP3M5X7stuD7N4r3uP2PZQUx) of the New Contributor workshop has been posted, and an outline of the video content can be found [here](/events/2018/05-contributor-summit). 

# Community

If you haven't noticed by now, we have a large, lively, and friendly open-source community.
We depend on new people becoming members and regular code contributors, so we would like you to come join us!
The [Community Membership Document](/community-membership.md) covers membership processes and roles.

## Communication

- [General Information](/communication)

## Events

Kubernetes participates in KubeCon + CloudNativeCon, held three times per year in China, Europe and in North America.
Information about these and other community events is available on the CNCF [events](https://www.cncf.io/events/) pages.

### Meetups

We follow the general [Cloud Native Computing Foundation guidelines](https://github.com/cncf/meetups) for Meetups.
You may also contact Paris Pittman via direct message on Kubernetes Slack (@paris) or by email (parispittman@google.com)

## Mentorship

Please learn about our mentoring initiatives [here](http://git.k8s.io/community/mentoring/README.md).
Feel free to ask us anything during our [Meet Our Contributors](https://github.com/kubernetes/community/blob/master/mentoring/programs/meet-our-contributors.md) to connect with us.

# Advanced Topics

This section includes things that need to be documented, but typical contributors do not need to interact with regularly.

- [OWNERS files](owners.md) - The Kubernetes organizations are managed with OWNERS files, which outline which parts of the code are owned by what groups.
